"""Public storefront routes."""

from django.urls import path

from ..views import storefront as views

app_name = "storefront"

urlpatterns = [
    path("<slug:slug>/item/<int:listing_id>/", views.item_detail, name="item"),
    path("<slug:slug>/", views.detail, name="detail"),
]
