{% extends 'shop/base.html' %}
{% load i18n %}

{% block content %}
<h2 class="mb-3">{% trans "Delete shop" %}</h2>
<p>{% blocktrans with name=shop.name %}Are you sure you want to delete "{{ name }}"?{% endblocktrans %}</p>
<form method="post">
    {% csrf_token %}
    <button type="submit" class="btn btn-danger">{% trans "Delete" %}</button>
    <a href="{% url 'backoffice:index' %}" class="btn btn-secondary">{% trans "Cancel" %}</a>
</form>
{% endblock %}
