# Generated by Django 5.2.14 on 2026-06-30 21:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shop', '0002_alter_general_options_shop'),
    ]

    operations = [
        migrations.AddField(
            model_name='shop',
            name='enabled_sections',
            field=models.JSONField(blank=True, default=list),
        ),
    ]
