# Generated by Django 5.2.14 on 2026-07-01 16:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shop', '0010_hulllisting_featured'),
    ]

    operations = [
        migrations.AddField(
            model_name='shop',
            name='description',
            field=models.TextField(blank=True, default=''),
        ),
    ]
