# Generated by Django 5.2.14 on 2026-06-30 21:56

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('memberaudit', '0020_add_new_roles'),
        ('shop', '0004_hulllisting_hulllistingsource_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='ShopSource',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('section', models.CharField(choices=[('hulls', 'Hulls')], max_length=20)),
                ('container_item_id', models.PositiveBigIntegerField(blank=True, null=True)),
                ('character', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='memberaudit.character')),
                ('location', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='memberaudit.location')),
                ('shop', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='sources', to='shop.shop')),
            ],
        ),
        migrations.DeleteModel(
            name='HullListingSource',
        ),
    ]
