# Generated by Django 5.2.14 on 2026-07-01 13:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shop', '0007_shopsource_price_mode_shopsource_price_pct'),
    ]

    operations = [
        migrations.AddField(
            model_name='shopsource',
            name='container_name',
            field=models.CharField(blank=True, default='', max_length=100),
        ),
    ]
