{% load static %}
<!DOCTYPE html>
<html lang="en" data-theme="dark">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>{% block title %}{{ shop.name }}{% endblock %}</title>
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/@tabler/icons-webfont@3.44.0/dist/tabler-icons.min.css"
          integrity="sha512-lN84NfQHM5zFEciWFvS3+AT7M8WTKA5QNTn7x7eK7W+V74EglzVYc7PkoQW4sFvIg/5+PPdwp3nd4DUS+Szihw=="
          crossorigin="anonymous" referrerpolicy="no-referrer">
    <link rel="stylesheet" href="{% static 'shop/storefront.css' %}">
</head>
<body class="min-h-screen bg-base-100 text-base-content flex flex-col">
    <header class="border-b border-base-300 bg-base-200/60">
        <div class="max-w-6xl mx-auto px-4 py-4 flex items-center justify-between gap-4">
            <h1 class="text-2xl font-bold tracking-tight">{% block header %}{{ shop.name }}{% endblock %}</h1>
            {# reserved for future section tabs + "Login with EVE SSO" #}
            <nav class="text-sm text-base-content/40">{% block header_nav %}{% endblock %}</nav>
        </div>
    </header>

    <main class="max-w-6xl mx-auto w-full px-4 py-8 flex-1">
        {% block content %}{% endblock %}
    </main>

    <footer class="border-t border-base-300 bg-base-200/60">
        <div class="max-w-6xl mx-auto px-4 py-6 text-center text-xs text-base-content/50">
            <p>&copy; 2014 CCP hf. All rights reserved. "EVE", "EVE Online", "CCP",
               and all related logos and images are trademarks or registered trademarks of CCP hf.</p>
        </div>
    </footer>
</body>
</html>
