# Generated by Django 5.2.14 on 2026-07-01 11:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shop', '0005_shopsource_delete_hulllistingsource'),
    ]

    operations = [
        migrations.AddField(
            model_name='hulllisting',
            name='price_mode',
            field=models.CharField(choices=[('fixed', 'Fixed'), ('jita_buy_pct', '% Jita Buy'), ('jita_sell_pct', '% Jita Sell')], default='fixed', max_length=20),
        ),
        migrations.AddField(
            model_name='hulllisting',
            name='price_pct',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True),
        ),
        migrations.AddField(
            model_name='hulllisting',
            name='stock_mode',
            field=models.CharField(choices=[('auto', 'Auto'), ('fixed', 'Fixed')], default='auto', max_length=10),
        ),
    ]
