# Generated by Django 5.2.14 on 2026-06-30 20:07

import django.core.validators
import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('eveonline', '0025_remove_evecharacter_last_updated_and_more'),
        ('shop', '0001_initial'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='general',
            options={'default_permissions': (), 'managed': False, 'permissions': (('basic_access', 'Can access the shop app'), ('manage_corporation_shops', 'Can manage corporation shops'))},
        ),
        migrations.CreateModel(
            name='Shop',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.SlugField(help_text='Globally unique. Lowercase letters, numbers and dashes.', unique=True, validators=[django.core.validators.RegexValidator(message='Slug may contain lowercase letters, numbers and single dashes only.', regex='^[a-z0-9]+(-[a-z0-9]+)*$')])),
                ('name', models.CharField(max_length=100)),
                ('shop_type', models.CharField(choices=[('personal', 'Personal'), ('corporation', 'Corporation')], default='personal', max_length=12)),
                ('is_published', models.BooleanField(default=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('corporation', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='shops', to='eveonline.evecorporationinfo')),
                ('created_by', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='shops', to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
