# Generated by Django 5.2.14 on 2026-07-01 12:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shop', '0006_hulllisting_price_mode_hulllisting_price_pct_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='shopsource',
            name='price_mode',
            field=models.CharField(choices=[('fixed', 'Fixed'), ('jita_buy_pct', '% Jita Buy'), ('jita_sell_pct', '% Jita Sell')], default='fixed', max_length=20),
        ),
        migrations.AddField(
            model_name='shopsource',
            name='price_pct',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True),
        ),
    ]
