{% extends 'allianceauth/base-bs5.html' %}
{% load i18n %}

{% block page_title %}{% trans "Shop" %}{% endblock %}
{% block header_nav_brand %}{% trans "Shop" %}{% endblock %}
{% block header_nav_user_character_control %}{% endblock %}

{% block content %}{% endblock %}
