# Generated by Django 5.2.14 on 2026-07-01 15:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shop', '0009_hulllisting_persist'),
    ]

    operations = [
        migrations.AddField(
            model_name='hulllisting',
            name='featured',
            field=models.BooleanField(default=False),
        ),
    ]
